@@ -16,9 +16,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # Start with clean directories and no leftover links.txt
-rm -rf man* links.txt
-
-mkdir man0 man1 man2 man3 man4 man5 man6 man7 man8
+rm -rf man* links.txt untranslated.txt
 
 # Process packages
 while read line; do
@@ -41,24 +39,10 @@ while read line; do
 		echo "Warning: Could not find .pkg.tar.xz for package '$package'"
 	else
 		tar xaf $latest_pkg --directory=tmp 2>/dev/null
-		../move-manpages.sh
+		../move-manpages.sh "$package"
 	fi
 	# Finally, remove the tarball, so that the regexp
 	# matching does not match the wrong tarball.
 	# See pacman and pacman-contrib for an example.
 	rm -rf tmp
 done < packages.txt
-
-if [ -f links.txt ]; then
-	LC_ALL=C sort links.txt > tmp.links
-	mv tmp.links links.txt
-fi
-
-# Another special case for man.7, which uses \c and
-# is therefore not translatable by po4a.
-# Reformat the part to display equally in the man browser.
-# Line 272 and 273:
-# .B \&.UE \c
-# .RI [ trailer ]
-# Reformat to: \fB\&.UE\fP [ \fItrailer\fP ]
-sed -i -e "/^\.B \\\&\.UE \\\c/{N; s/.*/\\\fB\\\\\&.UE\\\fP [ \\\fItrailer\\\fP ]/}" man7/man.7
